Crate libtest2_harness

An experimental replacement for the core of libtest

Usage

To use this, you most likely want to add a manual [[test]] section to Cargo.toml and set harness = false. For example:

[[test]]
name = "mytest"
path = "tests/mytest.rs"
harness = false

And in tests/mytest.rs you would call Harness::main in the main function:

libtest2_harness::Harness::with_env()
    .main();

Modules

cli

Structs

Harness
RunError
State

Enums

RunMode
TestKind
Type of the test according to the rust book conventions.

Traits

Case

Type Aliases

RunResult